@@ -12,16 +12,19 @@ const platforms = sauceBrowsers([
   { name: 'firefox', version: ['oldest', 'latest'] },
   { name: 'internet explorer', version: 'oldest..latest' },
   { name: 'iphone', version: ['oldest', 'latest'] },
-  { name: 'opera', version: 'oldest..latest' },
   { name: 'safari', version: 'oldest..latest' },
   { name: 'microsoftedge', version: 'oldest..latest' }
 ]).then((platforms) => {
   return platforms.map((platform) => {
-    return {
+    const ret = {
       browserName: platform.api_name,
       version: platform.short_version,
       platform: platform.os
     };
+
+    if (ret.browserName === 'android') ret.deviceName = platform.long_name;
+
+    return ret;
   });
 });
 
