@@ -29,8 +29,53 @@ describe('url-parse', function () {
     assume(url.hostname).to.be.a('string');
   });
 
+  it('works when the global variable is not defined', function () {
+    var globalVar = global;
+    global = undefined;
+    var url = parse('http://google.com/?foo=bar', true);
+
+    assume(url).to.be.an('object');
+    assume(url.pathname).to.be.a('string');
+    assume(url.host).to.be.a('string');
+    assume(url.hostname).to.be.a('string');
+
+    global = globalVar;
+  });
+
+  describe('trimLeft', function () {
+    it('is a function', function () {
+      assume(parse.trimLeft).is.a('function');
+    });
+
+    it('removes whitespace on the left', function () {
+      assume(parse.trimLeft('  lol')).equals('lol');
+    });
+
+    it('calls toString on a given value', function () {
+      //
+      // When users pass in `window.location` it's not an actual string
+      // so you can't replace on it. So it needs to be cast to a string.
+      //
+      var fake = {
+        toString: function () {
+          return 'wat';
+        }
+      };
+
+      assume(parse.trimLeft(fake)).equals('wat');
+    });
+  });
+
   describe('extractProtocol', function () {
     it('extracts the protocol data', function () {
+      assume(parse.extractProtocol('http://example.com')).eql({
+        slashes: true,
+        protocol: 'http:',
+        rest: 'example.com'
+      });
+    });
+
+    it('extracts the protocol data for nothing', function () {
       assume(parse.extractProtocol('')).eql({
         slashes: false,
         protocol: '',
@@ -47,6 +92,14 @@ describe('url-parse', function () {
         rest: input
       });
     });
+
+    it('trimsLeft', function () {
+      assume(parse.extractProtocol(' javascript://foo')).eql({
+        slashes: true,
+        protocol: 'javascript:',
+        rest: 'foo'
+      });
+    });
   });
 
   it('parses the query string into an object', function () {
@@ -179,6 +232,28 @@ describe('url-parse', function () {
     assume(parsed.pathname).equals('/b/c');
   });
 
+  it('ignores \\ in pathnames', function () {
+    var url = 'http://google.com:80\\@yahoo.com/#what\\is going on'
+      , parsed = parse(url);
+
+    assume(parsed.port).equals('');
+    assume(parsed.username).equals('');
+    assume(parsed.password).equals('');
+    assume(parsed.hostname).equals('google.com');
+    assume(parsed.hash).equals('#what\\is going on');
+
+    parsed = parse('//\\what-is-up.com');
+    assume(parsed.pathname).equals('/what-is-up.com');
+  });
+
+  it('correctly ignores multiple slashes //', function () {
+    var url = '////what-is-up.com'
+      , parsed = parse(url);
+
+    assume(parsed.host).equals('');
+    assume(parsed.hostname).equals('');
+  });
+
   describe('origin', function () {
     it('generates an origin property', function () {
       var url = 'http://google.com:80/pathname'
@@ -239,6 +314,13 @@ describe('url-parse', function () {
       o = parse('wss://google.com:80/pathname');
       assume(o.origin).equals('wss://google.com:80');
     });
+
+    it('maintains the port number for non-default port numbers', function () {
+      var parsed = parse('http://google.com:8080/pathname');
+
+      assume(parsed.host).equals('google.com:8080');
+      assume(parsed.href).equals('http://google.com:8080/pathname');
+    });
   });
 
   describe('protocol', function () {
@@ -455,6 +537,7 @@ describe('url-parse', function () {
       var tests = [
         ['', 'http://foo.com', ''],
         ['', 'http://foo.com/', '/'],
+        ['', 'http://foo.com/a', '/a'],
         ['a', 'http://foo.com', '/a'],
         ['a/', 'http://foo.com', '/a/'],
         ['b/c', 'http://foo.com/a', '/b/c'],
